==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/StyleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescription } from "./StyleDescription";
/**
 * @hidden
 */
var StyleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StyleDescriptionMetadata, _super);
    function StyleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StyleDescriptionMetadata.b = function (a) {
        if (StyleDescriptionMetadata.a == null) {
            StyleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StyleDescriptionMetadata.c(StyleDescriptionMetadata.a);
        }
        if (a.j(StyleDescriptionMetadata.a)) {
            return;
        }
        a.y(StyleDescriptionMetadata.a);
    };
    StyleDescriptionMetadata.c = function (a) {
    };
    StyleDescriptionMetadata.d = function (a) {
        StyleDescriptionMetadata.b(a);
        a.aa("Style", function () { return new StyleDescription(); });
        a.z("Style", StyleDescriptionMetadata.a);
    };
    StyleDescriptionMetadata.$t = markType(StyleDescriptionMetadata, 'StyleDescriptionMetadata');
    StyleDescriptionMetadata.a = null;
    return StyleDescriptionMetadata;
}(Base));
export { StyleDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/StyleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescription } from "./StyleDescription";
/**
 * @hidden
 */
var StyleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StyleDescriptionMetadata, _super);
    function StyleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StyleDescriptionMetadata.b = function (a) {
        if (StyleDescriptionMetadata.a == null) {
            StyleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StyleDescriptionMetadata.c(StyleDescriptionMetadata.a);
        }
        if (a.k(StyleDescriptionMetadata.a)) {
            return;
        }
        a.aa(StyleDescriptionMetadata.a);
    };
    StyleDescriptionMetadata.c = function (a) {
    };
    StyleDescriptionMetadata.d = function (a) {
        StyleDescriptionMetadata.b(a);
        a.ac("Style", function () { return new StyleDescription(); });
        a.ab("Style", StyleDescriptionMetadata.a);
    };
    StyleDescriptionMetadata.$t = markType(StyleDescriptionMetadata, 'StyleDescriptionMetadata');
    StyleDescriptionMetadata.a = null;
    return StyleDescriptionMetadata;
}(Base));
export { StyleDescriptionMetadata };
